==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebListDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListDescription } from "./WebListDescription";
/**
 * @hidden
 */
export let WebListDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebListDescriptionMetadata extends Base {
        static b(a) {
            if (WebListDescriptionMetadata.a == null) {
                WebListDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebListDescriptionMetadata.c(WebListDescriptionMetadata.a);
            }
            if (a.k(WebListDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebListDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:List");
            a.item("__tagNameWC", "String:igc-list");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Size", "ExportedType:string:SizableComponentSize");
            a.item("Size@names", "Large;Small;Medium");
        }
        static d(a) {
            WebListDescriptionMetadata.b(a);
            a.ad("WebList", () => new WebListDescription());
            a.ac("WebList", WebListDescriptionMetadata.a);
        }
    }
    WebListDescriptionMetadata.$t = markType(WebListDescriptionMetadata, 'WebListDescriptionMetadata');
    WebListDescriptionMetadata.a = null;
    return WebListDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebListDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListDescription } from "./WebListDescription";
/**
 * @hidden
 */
export let WebListDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebListDescriptionMetadata extends Base {
        static b(a) {
            if (WebListDescriptionMetadata.a == null) {
                WebListDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebListDescriptionMetadata.c(WebListDescriptionMetadata.a);
            }
            if (a.k(WebListDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebListDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:List");
            a.item("__tagNameWC", "String:igc-list");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebListDescriptionMetadata.b(a);
            a.ae("WebList", () => new WebListDescription());
            a.ad("WebList", WebListDescriptionMetadata.a);
        }
    }
    WebListDescriptionMetadata.$t = markType(WebListDescriptionMetadata, 'WebListDescriptionMetadata');
    WebListDescriptionMetadata.a = null;
    return WebListDescriptionMetadata;
})();
